@@ -13,10 +13,16 @@ class CTMDataset(Dataset):
             X : array-like, shape=(n_samples, n_features)
                 Document word matrix.
         """
+        if len(X) != len(X_bert):
+            raise Exception("Wait! BoW and Contextual Embeddings have different sizes! "
+                            "You might want to check if the BoW preparation method has removed some documents. ")
+
+
         self.X = X
         self.X_bert = X_bert
         self.idx2token = idx2token
 
+
     def __len__(self):
         """Return length of dataset."""
         return len(self.X)
